@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20200603';
+our $VERSION = '5.20200620';
 our %utilities;
 
 sub utilities {
@@ -1615,6 +1615,13 @@ my %delta = (
         removed => {
         }
     },
+    5.032000 => {
+        delta_from => 5.031011,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
